@@ -140,6 +140,10 @@ class SimultanObject(object):
                 self._referenced_components = [self._template_parser.create_python_object(x) for x in self._wrapped_obj.ReferencedComponents.Items]
         return self._referenced_components
 
+    @property
+    def referenced_assets(self):
+        return [x.Resource for x in self._wrapped_obj.ReferencedAssets.Items.Items]
+
     def __repr__(self):
         return f'{self.name}: ' + object.__repr__(self)
 
@@ -157,6 +161,7 @@ class SimultanObject(object):
         return idx
 
     def get_param(self, param):
+
         idx = self.get_param_index(param)
         if idx is None:
             raise AttributeError(f'{self} {self.name} {self.id} has no parameter {param}')
