@@ -368,12 +368,16 @@ class BaseGeometricFace(BaseGeoBaseClass):
         return f'Face {self.id}: {self.name}'
 
     @property
-    def components(self):
+    def _components(self):
         return self.geometry_model.get_geo_components(self._wrapped_obj)
 
+    @property
+    def components(self):
+        return self.geometry_model.get_py_geo_components(self._wrapped_obj)
+
     @property
     def construction_assignment(self):
-        return next((x for x in self.components if x.InstanceType == InstanceType.ALIGNED_WITH), None)
+        return next((x for x in self._components if x.InstanceType == InstanceType.ALIGNED_WITH), None)
 
     @property
     def construction(self):
@@ -386,6 +390,57 @@ class BaseGeometricFace(BaseGeoBaseClass):
         component = self.construction_assignment.ReferencedComponents.Items[0].Reference
         return self.geometry_model.template_parser.create_python_object(component, template_name='BuildInConstruction')
 
+    @property
+    def normal(self):
+        normal = self._wrapped_obj.get_Normal()
+        return np.array([normal.X, normal.Y, normal.Z])
+
+    @property
+    def orientation(self):
+        return self._wrapped_obj.get_Orientation()
+
+    @property
+    def side_1_volume(self):
+        volume = None
+        if not self._wrapped_obj.PFaces:
+            boundary_faces = set(self._wrapped_obj.Boundary.Faces)
+            if boundary_faces.__len__() == 2:
+                try:
+                    boundary_faces.remove(self._wrapped_obj)
+                except:
+                    pass
+
+                if boundary_faces.__len__() == 1:
+                    volume = self.__class__.get_obj_by_id(list(boundary_faces)[0].Id).side_1_volume
+        else:
+            for p_face in self._wrapped_obj.PFaces:
+                if p_face.Orientation == 1:
+                    volume = self._wrapped_obj.PFaces[0].Volume
+        return volume
+
+    @property
+    def side_2_volume(self):
+        volume = None
+        if not self._wrapped_obj.PFaces:
+            boundary_faces = set(self._wrapped_obj.Boundary.Faces)
+            if boundary_faces.__len__() == 2:
+                try:
+                    boundary_faces.remove(self._wrapped_obj)
+                except:
+                    pass
+
+                if boundary_faces.__len__() == 1:
+                    volume = self.__class__.get_obj_by_id(list(boundary_faces)[0].Id).side_2_volume
+        else:
+            for p_face in self._wrapped_obj.PFaces:
+                if p_face.Orientation == -1:
+                    volume = self._wrapped_obj.PFaces[0].Volume
+        return volume
+
+    @property
+    def hull_face(self):
+        return None in [self.side_1_volume, self.side_2_volume]
+
 
 class BaseGeometricVolume(BaseGeoBaseClass):
 
