@@ -44,7 +44,7 @@ class Template(object):
         @keyword documentation: Entry to document the template; str
         @keyword units: units of the content. Dictionary
         @keyword types: Dictionary with the type of the content. if the type is 'str' get_TextValue() is returned, param.get_ValueCurrent() otherwise
-        @keyword slots:
+        @keyword slots: Dictionary with the name of the content and the name of the slot where it is expected
 
         """
 
@@ -53,10 +53,10 @@ class Template(object):
 
         self.inherits_from = kwargs.get('inherits_from', None)
 
-        self.content = kwargs.get('content', None)
+        self.content = kwargs.get('content', [])
         self.documentation = kwargs.get('documentation', None)
-        self.units = kwargs.get('units', None)
-        self.types = kwargs.get('types', None)
+        self.units = kwargs.get('units', {})
+        self.types = kwargs.get('types', {})
 
         self.slots = kwargs.get('slots', {})
         self.synonyms = kwargs.get('synonyms', {})      # name of the attribute in the python class
